@@ -479,21 +479,22 @@ class Hanabot(SingleServerIRCBot):
         if not self._check_args(args, 0, [], event, 'join'):
             return 
 
-        # auto start new game if no active game in channel
         chan = event.target
-        if not chan in self.games:
-            self.handle_new(args, event)
-
         nick = event.source.nick
-        # enforce one game per player. Will not be needed if force users to 
-        # send commands from the channel, so I can key the game to the channel.
-        for chan, g in self.games.iteritems():
-            if nick in g.players():
-                msg = ('You are already in a game in %s. One game per nick '
-                       'per channel please.' % chan)
-                self._to_nick(event, msg)
-                return
 
+        # # enforce one game per player. Will not be needed if force users to 
+        # # send commands from the channel, so I can key the game to the channel.
+        # for chan, g in self.games.iteritems():
+        #     if nick in g.players():
+        #         msg = ('You are already in a game in %s. One game per nick '
+        #                'per channel please.' % chan)
+        #         self._to_nick(event, msg)
+        #         return
+
+        if not chan in self.games:
+            self._to_chan(event, 'There is no game started in %s, create one '
+                                 'with !new' % chan)
+            return
 
         if not self.channels[chan].is_voiced(nick):
             self.connection.privmsg('ChanServ', 'voice %s %s' % (chan, nick))
